Skip to contents

This function tokenizes comments that are to be used in collocate_comments_fuzzy() or collocate_comments()

Usage

tokenize_derivative(derivative_document, text_column)

Arguments

derivative_document

data frame containing derivative documents, where each row represents a document

text_column

string indicating the name of the column containing derivative text

Value

tokenized comments

Examples

# Tokenize the derivative document
toks_comment <- tokenize_derivative(comment_example, text_column="Notes")