R/tokenize_derivate.R
tokenize_derivative.Rd
This function tokenizes comments that are to be used in collocate_comments_fuzzy() or collocate_comments()
collocate_comments_fuzzy()
collocate_comments()
tokenize_derivative(derivative_document, text_column)
data frame containing derivative documents, where each row represents a document
string indicating the name of the column containing derivative text
tokenized comments
# Tokenize the derivative document toks_comment <- tokenize_derivative(comment_example, text_column="Notes")