Skip to contents

This function tokenizes a source document that is to be used in collocate_comments_fuzzy() or collocate_comments()

Usage

tokenize_source(transcript_file)

Arguments

transcript_file

data frame of the source document, where the source document text is in a column named text.

Value

a tokenized object

Examples

# Tokenize source document
toks_source <- tokenize_source(transcript_example)