R/tokenize_source.R
tokenize_source.Rd
This function tokenizes a source document that is to be used in collocate_comments_fuzzy() or collocate_comments()
collocate_comments_fuzzy()
collocate_comments()
tokenize_source(transcript_file)
data frame of the source document, where the source document text is in a column named text.
a tokenized object
# Tokenize source document toks_source <- tokenize_source(transcript_example)